@@ -2,7 +2,7 @@
 # coding: utf-8
 # /*##########################################################################
 #
-# Copyright (c) 2016-2019 European Synchrotron Radiation Facility
+# Copyright (c) 2016-2021 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -161,7 +161,7 @@ def main(argv):
     plot.getStatsWidget().parent().setVisible(True)
 
     plot.show()
-    app.exec_()
+    app.exec()
     updateThread.stop()  # Stop updating the plot
 
 
